==> faircli-0.0.25.tar.gz: templates/fair_samples/lib/main.dart <==
import 'dart:convert';

import 'package:fair/fair.dart';
import 'package:fair_pushy/fair_pushy.dart';
import 'package:fair_pushy/src/files/fair_file.dart';
import 'package:fair_samples/plugins/net/fair_net_plugin.dart';
import 'package:flutter/material.dart';

import 'datasource/fair_test_data.dart';
import 'delegate/listview_common_delegate.dart';
import 'extension/ext.dart';
import 'src/module.fair.dart' as g;

@FairBinding(packages: [
  'package:flutter_staggered_grid_view/src/widgets/staggered_grid.dart',
  'package:flutter_staggered_grid_view/src/widgets/masonry_grid_view.dart',
])
Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  FairPushy.init(debug: true);

  //Android应该是: storage/emulated/0/Android/data/com.demo_carrier/files/fairPushy/files/debug
  final devDir = await FairFile.getMainFolder();
  final devPath = '${devDir?.path}/files/debug';

  //这里的path是item的fair bundle产物
  FairDevTools.fairWidgetBuilder = (name, path) {
    ///纯item模版展示逻辑，一般item不会有decoration，所以套一个scaffold
    if ((name as String).contains('_item')) {
      return Scaffold(
        appBar: AppBar(
          title: Text(name),
        ),
        body: FairWidget(name: name, path: path, data: {
          'fairProps': jsonEncode(dataLogicMap.fuzzyMatching(name)),
        }),
      );
    } else if (templateWithNoItem.fuzzyMatching(name)) {
      ///只有父布局动态化没有动态化item的模版/写死数据的模版以及listview_template展示逻辑
      return FairWidget(name: name, path: path, data: {
        'fairProps': jsonEncode(dataLogicMap.fuzzyMatching(name)),
      });
    } else {
      ///其他动态化component模版展示逻辑
      return FairWidget(
          name: name,
          path: path,
          delegate: ListviewCommonDelegate(
              path: '$devPath/${name}_item.fair.json', //此处只兼容一种item的情况，后续可能需要扩展
              dataSource: itemDataLogicMap.fuzzyMatching(name)), //对应下标item数据源
          data: {
            'fairProps': jsonEncode(dataLogicMap.fuzzyMatching(name)),
            //外部列表动态化也可能会有数据源，但是目前demo模版没有，暂不处理
          });
    }
  };
  FairDevTools.config = FairDevConfig()
    ..addEnv(OnlineEnvInfo(
        envName: '环境1',
        updateUrl: 'https://fangfe.58.com/fairapp/module_patch_bundle',
        readOnly: true))
    ..addEnv(OnlineEnvInfo(envName: '环境2', updateUrl: '', readOnly: false));

  FairApp.runApplication(
    FairApp(
      generated: g.FairAppModule(),
      child: MyApp(),
    ),
    plugins: {'FairNet': FairNet()},
  );
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Fair Samples',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        // Here we take the value from the MyHomePage object that was created by
        // the App.build method, and use it to set our appbar title.
        title: Text('fair组件模板'),
      ),
      body: ListView(
        children: [
          addItem('Fair开发者选项', () {
            FairDevTools.openDevPage(context);
          }),
          addItem('以下是 组件模板 ↓↓↓↓↓↓↓↓↓', () {}),
          addItem('Listview >>>', () {
            showWidget(
                fairName: 'lib_template_hotel_listview_hotel_listview_template',
                fairPath:
                    'assets/fair/lib_template_hotel_listview_hotel_listview_template.fair.json');
          }),
          addItem('Scrollview >>>', () {
            showWidget(
                fairName: 'lib_template_scrollview_home_scrollview',
                fairPath:
                    'assets/fair/lib_template_scrollview_home_scrollview.fair.json');
          }),
          addItem('Gridview >>>', () {
            showWidget(
                fairName: 'lib_template_gridview_gridview_template',
                fairPath:
                    'assets/fair/lib_template_gridview_gridview_template.fair.json');
          }),
          addItem('PageView >>>', () {
            showWidget(
                fairName: 'lib_template_pageview_pageview_template',
                fairPath:
                    'assets/fair/lib_template_pageview_pageview_template.fair.json');
          }),
          addItem('StaggeredView >>>', () {
            showWidget(
                fairName: 'lib_template_staggered_view_staggeredview_template',
                fairPath:
                    'assets/fair/lib_template_staggered_view_staggeredview_template.fair.json');
          }),
          addItem('AppBar >>>', () {
            showWidget(
                fairName: 'lib_template_appbar_appbar_template',
                fairPath:
                    'assets/fair/lib_template_appbar_appbar_template.fair.json');
          }),
          addItem('FAB >>>', () {
            showWidget(
                fairName: 'lib_template_fab_fab_template',
                fairPath:
                    'assets/fair/lib_template_fab_fab_template.fair.json');
          }),
          addItem('Drawer >>>', () {
            showWidget(
                fairName: 'lib_template_drawer_drawer_template',
                fairPath:
                    'assets/fair/lib_template_drawer_drawer_template.fair.json');
          }),
          addItem('以下是 页面模板 ↓↓↓↓↓↓↓↓↓', () {}),
          addItem('Login >>>', () {
            showWidget(
                fairName: 'lib_template_login_page_login_page_template',
                fairPath:
                    'assets/fair/lib_template_login_page_login_page_template.fair.json');
          }),
          addItem('Detail >>>', () {
            showWidget(
                fairName: 'lib_template_detail_page_fair_detail',
                fairPath:
                    'assets/fair/lib_template_detail_page_fair_detail.fair.json');
          }),
          addItem('ListPage >>>', () {
            showWidget(
                fairName: 'lib_template_list_page_list_page',
                fairPath:
                    'assets/fair/lib_template_list_page_list_page.fair.json');
          }),
          addItem('ListCard >>>', () {
            showWidget(
                fairName: 'lib_template_list_card_moments_list',
                fairPath:
                    'assets/fair/lib_template_list_card_moments_list.fair.json');
          }),
          addItem('TabBar >>>', () {
            showWidget(
                fairName: 'lib_template_tabbar_page_tabbar_page',
                fairPath:
                    'assets/fair/lib_template_tabbar_page_tabbar_page.fair.json');
          }),
        ],
      ),
    );
  }

  void showWidget({required fairPath, required fairName}) {
    Navigator.of(context).push(MaterialPageRoute(builder: (_) {
      return FairDevTools.fairWidgetBuilder(fairName, fairPath);
    }));
  }

  Widget addItem(String itemName, dynamic onPress) {
    return GestureDetector(
        onTap: onPress,
        child: Container(
            alignment: Alignment.centerLeft,
            height: 70,
            decoration: BoxDecoration(
                color: Colors.white,
                border: Border(
                    bottom: BorderSide(
                        color: Colors.grey.withOpacity(0.5), width: 0.5))),
            padding: const EdgeInsets.only(left: 20.0),
            child: Text(
              itemName,
              style: const TextStyle(
                fontSize: 20,
                fontWeight: FontWeight.bold,
              ),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
              textAlign: TextAlign.left,
            )));
  }
}

==> faircli-0.0.28.tar.gz: templates/fair_samples/lib/main.dart <==
import 'dart:convert';

import 'package:fair/fair.dart';
import 'package:fair_pushy/fair_pushy.dart';
import 'package:fair_samples/plugins/net/fair_net_plugin.dart';
import 'package:flutter/material.dart';

import 'src/module.fair.dart' as g;

@FairBinding(packages: [
  'package:flutter_staggered_grid_view/src/widgets/staggered_grid.dart',
  'package:flutter_staggered_grid_view/src/widgets/masonry_grid_view.dart',
])
Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  FairPushy.init(debug: true);

  //这里的path是item的fair bundle产物
  FairDevTools.fairWidgetBuilder = (name, path) {
    return FairWidget(name: name, path: path, data: {
      'fairProps': jsonEncode({}),
    });
  };
  FairDevTools.config = FairDevConfig()
    ..addEnv(OnlineEnvInfo(
        envName: '环境1',
        updateUrl: 'https://fangfe.58.com/fairapp/module_patch_bundle',
        readOnly: true))
    ..addEnv(OnlineEnvInfo(envName: '环境2', updateUrl: '', readOnly: false));

  FairApp.runApplication(
    FairApp(
      generated: g.FairAppModule(),
      child: MyApp(),
    ),
    plugins: {'FairNet': FairNet()},
  );
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Fair Samples',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        // Here we take the value from the MyHomePage object that was created by
        // the App.build method, and use it to set our appbar title.
        title: Text('fair组件模板'),
      ),
      body: ListView(
        children: [
          addItem('Fair开发者选项', () {
            FairDevTools.openDevPage(context);
          }),
          addItem('以下是 组件模板 ↓↓↓↓↓↓↓↓↓', () {}),
          addItem('Listview >>>', () {
            showWidget(
                fairName: 'lib_template_hotel_listview_hotel_listview_template',
                fairPath:
                    'assets/fair/lib_template_hotel_listview_hotel_listview_template.fair.json');
          }),
          addItem('Scrollview >>>', () {
            showWidget(
                fairName: 'lib_template_scrollview_home_scrollview',
                fairPath:
                    'assets/fair/lib_template_scrollview_home_scrollview.fair.json');
          }),
          addItem('Gridview >>>', () {
            showWidget(
                fairName: 'lib_template_gridview_gridview_template',
                fairPath:
                    'assets/fair/lib_template_gridview_gridview_template.fair.json');
          }),
          addItem('PageView >>>', () {
            showWidget(
                fairName: 'lib_template_pageview_pageview_template',
                fairPath:
                    'assets/fair/lib_template_pageview_pageview_template.fair.json');
          }),
          addItem('StaggeredView >>>', () {
            showWidget(
                fairName: 'lib_template_staggered_view_staggeredview_template',
                fairPath:
                    'assets/fair/lib_template_staggered_view_staggeredview_template.fair.json');
          }),
          addItem('AppBar >>>', () {
            showWidget(
                fairName: 'lib_template_appbar_appbar_template',
                fairPath:
                    'assets/fair/lib_template_appbar_appbar_template.fair.json');
          }),
          addItem('FAB >>>', () {
            showWidget(
                fairName: 'lib_template_fab_fab_template',
                fairPath:
                    'assets/fair/lib_template_fab_fab_template.fair.json');
          }),
          addItem('Drawer >>>', () {
            showWidget(
                fairName: 'lib_template_drawer_drawer_template',
                fairPath:
                    'assets/fair/lib_template_drawer_drawer_template.fair.json');
          }),
          addItem('以下是 页面模板 ↓↓↓↓↓↓↓↓↓', () {}),
          addItem('Login >>>', () {
            showWidget(
                fairName: 'lib_template_login_page_login_page_template',
                fairPath:
                    'assets/fair/lib_template_login_page_login_page_template.fair.json');
          }),
          addItem('Detail >>>', () {
            showWidget(
                fairName: 'lib_template_detail_page_fair_detail',
                fairPath:
                    'assets/fair/lib_template_detail_page_fair_detail.fair.json');
          }),
          addItem('ListPage >>>', () {
            showWidget(
                fairName: 'lib_template_list_page_list_page',
                fairPath:
                    'assets/fair/lib_template_list_page_list_page.fair.json');
          }),
          addItem('ListCard >>>', () {
            showWidget(
                fairName: 'lib_template_list_card_moments_list',
                fairPath:
                    'assets/fair/lib_template_list_card_moments_list.fair.json');
          }),
          addItem('TabBar >>>', () {
            showWidget(
                fairName: 'lib_template_tabbar_page_tabbar_page',
                fairPath:
                    'assets/fair/lib_template_tabbar_page_tabbar_page.fair.json');
          }),
        ],
      ),
    );
  }

  void showWidget({required fairPath, required fairName}) {
    Navigator.of(context).push(MaterialPageRoute(builder: (_) {
      return FairDevTools.fairWidgetBuilder(fairName, fairPath);
    }));
  }

  Widget addItem(String itemName, dynamic onPress) {
    return GestureDetector(
        onTap: onPress,
        child: Container(
            alignment: Alignment.centerLeft,
            height: 70,
            decoration: BoxDecoration(
                color: Colors.white,
                border: Border(
                    bottom: BorderSide(
                        color: Colors.grey.withOpacity(0.5), width: 0.5))),
            padding: const EdgeInsets.only(left: 20.0),
            child: Text(
              itemName,
              style: const TextStyle(
                fontSize: 20,
                fontWeight: FontWeight.bold,
              ),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
              textAlign: TextAlign.left,
            )));
  }
}
